# Prod 20240131_allsky_v0.10.5_all_dec_base

Base production for all declinations lines with lstchain v0.10.5


```
lstmcpipe_generate_config PathConfigAllSkyFull --prod_id 20240131_allsky_v0.10.5_all_dec_base --dec_list dec_2276 dec_4822 dec_6166 dec_6676 dec_min_1802 dec_min_413
```

contact: Thomas V.